# ytph

[![PyPI - Version](https://img.shields.io/pypi/v/ytph.svg)](https://pypi.org/project/ytph)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ytph.svg)](https://pypi.org/project/ytph)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install ytph
```

## License

`ytph` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.


## Release Process

1. Find current version: `hatch version` (e.g., 0.0.4)
2. Upgrade version: `hatch version "0.0.5"`
3. Build: `hatch build`
4. Publish: `hatch publish`
